@@ -49,7 +49,8 @@ def get_environment_from_secrets_manager(
         return secrets_manager_data
 
     logger.info(
-        f"Reading settings from `snatch/{current_env}` (logger level: {log_level})..."
+        f"Reading settings from Secrets Manager:  "
+        f"`datasource/{current_env}/snatch` (logger level: {log_level})..."
     )
 
     secrets_manager_data.update(secrets.get_project_secrets())
@@ -100,6 +101,8 @@ def get_settings(environment: Optional[str], log_level: str):
             "datasource_ceis_url": get_datasource_url("datasource_ceis"),
             "cnep_secret_token": os.getenv("SNATCH_CNEP_SECRET_TOKEN", "foo"),
             "datasource_cnep_url": get_datasource_url("datasource_cnep"),
+            "serasa_secret_token": os.getenv("SNATCH_SERASA_SECRET_TOKEN", "foo"),
+            "datasource_serasa_url": get_datasource_url("datasource_serasa"),
         }
     }
     data_from_secrets = get_environment_from_secrets_manager(
